@@ -1,8 +1,11 @@
 import subprocess
 from shlex import split
+from typing import List
 
-def run(command: str) -> list[str]:
-    if not command: return []
+
+def run(command: str) -> List[str]:
+    if not command:
+        return []
 
     result = subprocess.run(split(command), capture_output=True, check=True, text=True)
 
